===============================================
Amazon Web Services Cloud Watch Metrics library
===============================================


.. image:: https://img.shields.io/pypi/v/awsme.svg
        :target: https://pypi.python.org/pypi/awsme

.. image:: https://img.shields.io/travis/peterdemin/awsme.svg
        :target: https://travis-ci.org/peterdemin/awsme

.. image:: https://readthedocs.org/projects/awsme/badge/?version=latest
        :target: https://awsme.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/peterdemin/awsme/shield.svg
     :target: https://pyup.io/repos/github/peterdemin/awsme/
     :alt: Updates



Client AWS CW library to send metrics efficiently


* Free software: MIT license
* Documentation: https://awsme.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `elgertam/cookiecutter-pipenv`_ project template, based on `audreyr/cookiecutter-pypackage`_.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`elgertam/cookiecutter-pipenv`: https://github.com/elgertam/cookiecutter-pipenv
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
